@@ -39,7 +39,10 @@
 #include <glib/gi18n-lib.h>
 
 #include "e-book-backend-file.h"
+
+#ifdef HAVE_LIBDB
 #include "e-book-backend-file-migrate-bdb.h"
+#endif
 
 #define E_BOOK_BACKEND_FILE_GET_PRIVATE(obj) \
 	(G_TYPE_INSTANCE_GET_PRIVATE \
@@ -378,7 +381,27 @@ hard_link_photo (EBookBackendFile *bf,
 
 		i++;
 
+		#ifdef G_OS_WIN32
+		{
+		GFile *src_file = g_file_new_for_path (src_filename);
+		GFile *dst_file = g_file_new_for_path (fullname);
+		GError *copy_error = NULL;
+
+		g_file_copy (src_file, dst_file, G_FILE_COPY_NONE,
+		             NULL, NULL, NULL, &copy_error);
+
+		if (copy_error != NULL) {
+			g_error_free (copy_error);
+			ret = -1;
+		} else
+			ret = 0;
+
+		g_object_unref (src_file);
+		g_object_unref (dst_file);
+		}
+		#else
 		ret = link (src_filename, fullname);
+		#endif
 
 	} while (ret < 0 && errno == EEXIST);
 
@@ -1962,8 +1985,10 @@ book_backend_file_initable_init (GInitable *initable,
 	ESourceRegistry *registry;
 	ESource *source;
 	const gchar *extension_name;
-	gchar *backup, *dirname;
-	gchar *filename, *fullpath;
+#ifdef HAVE_LIBDB
+	gchar *backup, *filename;
+#endif /* HAVE_LIBDB */
+	gchar *dirname, *fullpath;
 	gboolean success = TRUE;
 
 	priv = E_BOOK_BACKEND_FILE_GET_PRIVATE (initable);
@@ -1981,9 +2006,11 @@ book_backend_file_initable_init (GInitable *initable,
 		dirname = e_book_backend_file_extract_path_from_source (
 			registry, source, GET_PATH_DB_DIR);
 
+	fullpath = g_build_filename (dirname, "contacts.db", NULL);
+
+#ifdef HAVE_LIBDB
 	filename = g_build_filename (dirname, "addressbook.db", NULL);
 	backup = g_build_filename (dirname, "addressbook.db.old", NULL);
-	fullpath = g_build_filename (dirname, "contacts.db", NULL);
 
 	/* The old BDB exists, lets migrate that to sqlite right away. */
 	if (g_file_test (filename, G_FILE_TEST_EXISTS)) {
@@ -2018,6 +2045,7 @@ book_backend_file_initable_init (GInitable *initable,
 			goto exit;
 		}
 	}
+#endif /* HAVE_LIBDB */
 
 	/* If we already have a handle on this, it means there
 	 * was an old BDB migrated and no need to reopen it. */
@@ -2081,8 +2109,10 @@ book_backend_file_initable_init (GInitable *initable,
 exit:
 	g_free (dirname);
 	g_free (fullpath);
+#ifdef HAVE_LIBDB
 	g_free (filename);
 	g_free (backup);
+#endif /* HAVE_LIBDB */
 
 	return success;
 }
