@@ -874,20 +874,17 @@ junk_test (struct _CamelSExp *f,
 	gboolean message_is_junk = FALSE;
 	GError *error = NULL;
 
-	junk_filter = camel_session_get_junk_filter (fms->session);
-	if (junk_filter == NULL)
-		goto exit;
-
 	/* Check if the message is already classified. */
 
 	flags = camel_message_info_flags (info);
 
 	if (flags & CAMEL_MESSAGE_JUNK) {
+		message_is_junk = TRUE;
 		if (camel_debug ("junk"))
 			printf (
 				"Message has a Junk flag set already, "
 				"skipping junk test...\n");
-		goto exit;
+		goto done;
 	}
 
 	if (flags & CAMEL_MESSAGE_NOTJUNK) {
@@ -895,9 +892,22 @@ junk_test (struct _CamelSExp *f,
 			printf (
 				"Message has a NotJunk flag set already, "
 				"skipping junk test...\n");
-		goto exit;
+		goto done;
 	}
 
+	/* If the sender is known, the message is not junk.
+	   Do this before header test, to be able to override server-side set headers. */
+
+	sender_is_known = camel_session_lookup_addressbook (
+		fms->session, camel_message_info_from (info));
+	if (camel_debug ("junk"))
+		printf (
+			"Sender '%s' in book? %d\n",
+			camel_message_info_from (info),
+			sender_is_known);
+	if (sender_is_known)
+		goto done;
+
 	/* Check the headers for a junk designation. */
 
 	ht = camel_session_get_junk_headers (fms->session);
@@ -925,21 +935,41 @@ junk_test (struct _CamelSExp *f,
 		node = node->next;
 	}
 
-	/* If the sender is known, the message is not junk. */
+	/* Not every message info has headers available, thus try headers of the message itself */
+	message = camel_filter_search_get_message (fms, f);
+	if (message) {
+		struct _camel_header_raw *h;
 
-	sender_is_known = camel_session_lookup_addressbook (
-		fms->session, camel_message_info_from (info));
-	if (camel_debug ("junk"))
-		printf (
-			"Sender '%s' in book? %d\n",
-			camel_message_info_from (info),
-			sender_is_known);
-	if (sender_is_known)
+		for (h = CAMEL_MIME_PART (message)->headers; h; h = h->next) {
+			const gchar *value;
+
+			if (!h->name)
+				continue;
+
+			value = g_hash_table_lookup ((GHashTable *) ht, h->name);
+			if (!value)
+				continue;
+
+			message_is_junk = camel_strstrcase (h->value, value) != NULL;
+
+			if (message_is_junk) {
+				if (camel_debug ("junk"))
+					printf (
+						"Message contains \"%s: %s\"",
+						h->name, value);
+				goto done;
+			}
+		}
+	} else {
 		goto done;
+	}
 
 	/* Consult 3rd party junk filtering software. */
 
-	message = camel_filter_search_get_message (fms, f);
+	junk_filter = camel_session_get_junk_filter (fms->session);
+	if (junk_filter == NULL)
+		goto done;
+
 	status = camel_junk_filter_classify (
 		junk_filter, message, NULL, &error);
 
@@ -967,7 +997,7 @@ junk_test (struct _CamelSExp *f,
 		}
 
 		if (camel_debug ("junk"))
-			g_print (
+			printf (
 				"Junk filter classification: %s\n",
 				status_desc);
 	} else {
@@ -977,13 +1007,12 @@ junk_test (struct _CamelSExp *f,
 		message_is_junk = FALSE;
 	}
 
-done:
+ done:
 	if (camel_debug ("junk"))
 		printf (
 			"Message is determined to be %s\n",
 			message_is_junk ? "*JUNK*" : "clean");
 
-exit:
 	r = camel_sexp_result_new (f, CAMEL_SEXP_RES_BOOL);
 	r->value.number = message_is_junk;
 
@@ -1016,6 +1045,7 @@ camel_filter_search_match (CamelSession *session,
 	CamelSExp *sexp;
 	CamelSExpResult *result;
 	gboolean retval;
+	GError *local_error = NULL;
 	gint i;
 
 	fms.session = session;
@@ -1024,7 +1054,7 @@ camel_filter_search_match (CamelSession *session,
 	fms.message = NULL;
 	fms.info = info;
 	fms.source = source;
-	fms.error = error;
+	fms.error = &local_error;
 
 	sexp = camel_sexp_new ();
 
@@ -1037,21 +1067,29 @@ camel_filter_search_match (CamelSession *session,
 
 	camel_sexp_input_text (sexp, expression, strlen (expression));
 	if (camel_sexp_parse (sexp) == -1) {
-		/* A filter search is a search through your filters,
-		 * ie. your filters is the corpus being searched thru. */
-		g_set_error (
-			error, CAMEL_ERROR, CAMEL_ERROR_GENERIC,
-			_("Error executing filter search: %s: %s"),
-			camel_sexp_error (sexp), expression);
+		if (!local_error) {
+			/* A filter search is a search through your filters,
+			 * ie. your filters is the corpus being searched thru. */
+			g_set_error (
+				&local_error, CAMEL_ERROR, CAMEL_ERROR_GENERIC,
+				_("Error executing filter search: %s: %s"),
+				camel_sexp_error (sexp), expression);
+		}
 		goto error;
 	}
 
 	result = camel_sexp_eval (sexp);
 	if (result == NULL) {
-		g_set_error (
-			error, CAMEL_ERROR, CAMEL_ERROR_GENERIC,
-			_("Error executing filter search: %s: %s"),
-			camel_sexp_error (sexp), expression);
+		if (!local_error)
+			g_set_error (
+				&local_error, CAMEL_ERROR, CAMEL_ERROR_GENERIC,
+				_("Error executing filter search: %s: %s"),
+				camel_sexp_error (sexp), expression);
+		goto error;
+	}
+
+	if (local_error) {
+		camel_sexp_result_free (sexp, result);
 		goto error;
 	}
 
@@ -1074,5 +1112,8 @@ camel_filter_search_match (CamelSession *session,
 
 	g_object_unref (sexp);
 
+	if (local_error)
+		g_propagate_error (error, local_error);
+
 	return CAMEL_SEARCH_ERROR;
 }
