@@ -409,6 +409,7 @@ imapx_conn_manager_finalize (GObject *object)
 	priv = CAMEL_IMAPX_CONN_MANAGER_GET_PRIVATE (object);
 
 	g_rw_lock_clear (&priv->rw_lock);
+	g_weak_ref_clear (&priv->store);
 
 	/* Chain up to parent's finalize() method. */
 	G_OBJECT_CLASS (camel_imapx_conn_manager_parent_class)->finalize (object);
@@ -446,6 +447,7 @@ camel_imapx_conn_manager_init (CamelIMAPXConnManager *con_man)
 	con_man->priv = CAMEL_IMAPX_CONN_MANAGER_GET_PRIVATE (con_man);
 
 	g_rw_lock_init (&con_man->priv->rw_lock);
+	g_weak_ref_init (&con_man->priv->store, NULL);
 }
 
 static void
@@ -905,3 +907,22 @@ camel_imapx_conn_manager_close_connections (CamelIMAPXConnManager *con_man,
 
 	g_list_free_full (connections, (GDestroyNotify) connection_info_cancel_and_unref);
 }
+
+/* for debugging purposes only */
+void
+camel_imapx_conn_manager_dump_queue_status (CamelIMAPXConnManager *con_man)
+{
+	GList *list, *link;
+
+	g_return_if_fail (CAMEL_IS_IMAPX_CONN_MANAGER (con_man));
+
+	list = imapx_conn_manager_list_info (con_man);
+
+	for (link = list; link != NULL; link = g_list_next (link)) {
+		ConnectionInfo *cinfo = link->data;
+		camel_imapx_server_dump_queue_status (cinfo->is);
+		connection_info_unref (cinfo);
+	}
+
+	g_list_free (list);
+}
