@@ -274,6 +274,9 @@ struct _CamelIMAPXJob *
 						 guint32 job_type,
 						 const gchar *uid);
 
+/* for debugging purposes only */
+void		camel_imapx_server_dump_queue_status
+						(CamelIMAPXServer *imapx_server);
 G_END_DECLS
 
 #endif /* CAMEL_IMAPX_SERVER_H */
