@@ -324,7 +324,7 @@ imapx_update_message_info_flags (CamelMessageInfo *info,
 		changed = TRUE;
 	}
 
-	if ((folder->permanent_flags & CAMEL_MESSAGE_USER) != 0 && imapx_update_user_flags (info, server_user_flags))
+	if ((permanent_flags & CAMEL_MESSAGE_USER) != 0 && imapx_update_user_flags (info, server_user_flags))
 		changed = TRUE;
 
 	return changed;
@@ -336,7 +336,7 @@ imapx_set_message_info_flags_for_new_message (CamelMessageInfo *info,
                                               CamelFlag *server_user_flags,
 					      gboolean force_user_flags,
 					      CamelTag *user_tags,
-                                              CamelFolder *folder)
+					      guint32 permanent_flags)
 {
 	CamelMessageInfoBase *binfo = (CamelMessageInfoBase *) info;
 	CamelIMAPXMessageInfo *xinfo = (CamelIMAPXMessageInfo *) info;
@@ -346,7 +346,7 @@ imapx_set_message_info_flags_for_new_message (CamelMessageInfo *info,
 
 	xinfo->server_flags = server_flags;
 
-	if (force_user_flags || (folder->permanent_flags & CAMEL_MESSAGE_USER) != 0)
+	if (force_user_flags || (permanent_flags & CAMEL_MESSAGE_USER) != 0)
 		imapx_update_user_flags (info, server_user_flags);
 
 	while (user_tags) {
@@ -2773,7 +2773,7 @@ camel_imapx_parse_quota (CamelIMAPXInputStream *stream,
 	g_return_val_if_fail (out_quota_info != NULL, FALSE);
 
 	/* quota_response  ::= "QUOTA" SP astring SP quota_list
-	 * quota_list      ::= "(" #quota_resource ")"
+	 * quota_list      ::= "(" *quota_resource ")"
 	 * quota_resource  ::= atom SP number SP number */
 
 	success = camel_imapx_input_stream_astring (
@@ -2798,46 +2798,44 @@ camel_imapx_parse_quota (CamelIMAPXInputStream *stream,
 			goto fail;
 	}
 
-quota_resource:
-
-	success = camel_imapx_input_stream_atom (
-		stream, &token, &len, cancellable, error);
-
-	if (!success)
-		goto fail;
-
-	resource_name = g_strdup ((gchar *) token);
-
-	success = camel_imapx_input_stream_number (
-		stream, &resource_usage, cancellable, error);
-
-	if (!success)
-		goto fail;
-
-	success = camel_imapx_input_stream_number (
-		stream, &resource_limit, cancellable, error);
-
-	if (!success)
-		goto fail;
-
-	info = camel_folder_quota_info_new (
-		resource_name, resource_usage, resource_limit);
-	g_queue_push_tail (&queue, info);
-
-	g_free (resource_name);
-	resource_name = NULL;
-
-	tok = camel_imapx_input_stream_token (
-		stream, &token, &len, cancellable, error);
-	switch (tok) {
-		case IMAPX_TOK_ERROR:
-			goto fail;
-		case ')':
+	while (TRUE) {
+		/* Peek at the next token, and break
+		 * out of the loop if we get a close-paren. */
+		tok = camel_imapx_input_stream_token (
+			stream, &token, &len, cancellable, error);
+		if (tok == ')')
 			break;
-		default:
-			camel_imapx_input_stream_ungettoken (
-				stream, tok, token, len);
-			goto quota_resource;
+		if (tok == IMAPX_TOK_ERROR)
+			goto fail;
+		camel_imapx_input_stream_ungettoken (
+			stream, tok, token, len);
+
+		success = camel_imapx_input_stream_atom (
+			stream, &token, &len, cancellable, error);
+
+		if (!success)
+			goto fail;
+
+		resource_name = g_strdup ((gchar *) token);
+
+		success = camel_imapx_input_stream_number (
+			stream, &resource_usage, cancellable, error);
+
+		if (!success)
+			goto fail;
+
+		success = camel_imapx_input_stream_number (
+			stream, &resource_limit, cancellable, error);
+
+		if (!success)
+			goto fail;
+
+		info = camel_folder_quota_info_new (
+			resource_name, resource_usage, resource_limit);
+		g_queue_push_tail (&queue, info);
+
+		g_free (resource_name);
+		resource_name = NULL;
 	}
 
 	/* Eat the newline. */
