@@ -326,8 +326,7 @@ static void
 user_prompter_server_constructed (GObject *object)
 {
 	/* Chain up to parent's constructed() method. */
-	G_OBJECT_CLASS (e_user_prompter_server_parent_class)->
-		constructed (object);
+	G_OBJECT_CLASS (e_user_prompter_server_parent_class)->constructed (object);
 
 	e_extensible_load_extensions (E_EXTENSIBLE (object));
 }
