@@ -134,7 +134,7 @@ test_get_book_view_async (ETestServerFixture *fixture,
 		book, query,
 			(GSourceFunc) get_book_view_cb, fixture->loop);
 
-	g_timeout_add (5 * 1000, (GSourceFunc) main_loop_fail_timeout, NULL);
+	g_timeout_add_seconds (5, (GSourceFunc) main_loop_fail_timeout, NULL);
 	g_main_loop_run (fixture->loop);
 	e_book_query_unref (query);
 }
