@@ -26,9 +26,6 @@ gint
 main (gint argc,
       gchar **argv)
 {
-#if !GLIB_CHECK_VERSION (2, 35, 1)
-	g_type_init ();
-#endif
 	g_test_init (&argc, &argv, NULL);
 	g_test_bug_base ("http://bugzilla.gnome.org/");
 
